% [ff,g,H] = Q(X,f,paramf,E,paramE,I,paramI,mu)
% Quadratic-penalty function
%
% Q(x) = f(x) + ce²(x)/2µ + ([ci(x)]-)²/2µ
%
% In:
%   X: N x n list of row vectors.
%   f, paramf, E, paramE, I, paramI: as above.
%   mu: positive number (penalty parameter).
% Out:
%   ff: N x 1 list of function values.
%   g: N x n list of gradient vectors.
%   H: n x n x N list of Hessian matrices.

% Copyright (c) 2005 by Miguel A. Carreira-Perpinan

function [ff,g,H] = Q(X,f,paramf,E,paramE,I,paramI,mu)

